package edu.rice.comp211.laundry.garment;

/**
 * Abstract GarmentVisitor that provides default behavior for non-overridden methods.
 * Sub-classes merely have to supply a default return value and override only the methods that they need.
 * This is just a convenience class to simply coding under specific situations.   
 * There is NO requirement that Garment visitors be subclasses of this class!
 * @param <R> the return type of the visitor
 * @author swong
 *
 */
public abstract class AGarmentVisitor<R> implements GarmentVisitor<R> {

	/**
	 * The default return value returned by all non-overridden methods.
	 */
	private R defaultReturn;
	
	/**
	 * Constructor for the class
	 * @param defaultReturn the default value to return if a method is not overridden.
	 */
	public AGarmentVisitor(R defaultReturn){
		this.defaultReturn = defaultReturn;
	}

	@Override
	public R forShirt(Shirt s) {
		return defaultReturn;
	}

	@Override
	public R forPants(Pants p) {
		return defaultReturn;
	}

	@Override
	public R forSocks(Socks s) {
		return defaultReturn;
	}

	@Override
	public R forNullGarment(NullGarment g) {
		return defaultReturn;
	}

}
