package edu.rice.comp211.laundry.garment;

/** Garment :: = Shirt | Pants | Socks */

/**
 * Root class of the Garment union.  Represents an abstract garment.
 */
public abstract class Garment {
   // adjective = "" behaves like no adjective
   private final String adjective;

   protected Garment(final String pAdjective) {
      adjective = pAdjective;
   }

   /**
    * Accessor for the adjective
    * @return the garment's adjective
    */
   public String adjective() {
      return adjective;
   }

   /**
    * Executes ("accepts") a visitor for this garment
    * @param <R> The return type of the visitor (determined by the visitor being used)
    * @param v The visitor to accept
    * @return The return value of the visitor
    */
   public abstract <R> R accept(GarmentVisitor<R> v);

   /**
    * Returns true if to Garments are the same class and have the same adjective string.
    */
   public boolean equals(Object elt) {
      return (getClass() == elt.getClass()) && adjective.equals(((Garment) elt).adjective);
   }
}
