/*
 * Copyright (C) 2006 Sun Microsystems, Inc. All rights reserved. Use is
 * subject to license terms.
 */

package edu.rice.comp211.laundry.ui;

import edu.rice.comp211.laundry.garment.Garment;

import javax.swing.*;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;
import javax.swing.border.LineBorder;
import java.awt.*;
import java.net.URL;

/**
 * ListCellRenderer for the PasswordEntrys.
 *
 * @author sky
 */
final class LaundryListCellRenderer extends JPanel implements ListCellRenderer {
   /**
	 * 
	 */
	private static final long serialVersionUID = 5105975357874124441L;

private static final int LIST_CELL_ICON_SIZE = 60;

   private JLabel descLabel;

   public LaundryListCellRenderer() {
      super(new BorderLayout());

      descLabel = new JLabel();
      add(descLabel, BorderLayout.CENTER);

      setBorder(new CompoundBorder(new LineBorder(Color.BLACK, 1), new EmptyBorder(1, 1, 1, 1)));

      setOpaque(true);
   }

   public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
      if (value instanceof Garment) {
         final Garment garment = (Garment) value;
         String host = garment.adjective() + " " + garment.getClass().getSimpleName().toLowerCase();

         descLabel.setFont(new Font(Font.SERIF, Font.PLAIN, 10));
         descLabel.setText(host);
         descLabel.setIcon(getImageIcon(garment, LIST_CELL_ICON_SIZE));
      } else if (value instanceof String) {
         descLabel.setFont(new Font(Font.SERIF, Font.BOLD, 14));
         descLabel.setIcon(null);
         descLabel.setText(value.toString());
      } else {
         descLabel.setFont(new Font(Font.SERIF, Font.BOLD, 14));
         descLabel.setIcon(null);
         descLabel.setText("==========");
      }

      descLabel.setHorizontalAlignment(JLabel.CENTER);
      descLabel.setVerticalTextPosition(JLabel.BOTTOM);
      descLabel.setHorizontalTextPosition(JLabel.CENTER);

      adjustColors(list.getBackground(), list.getForeground(), this, descLabel);
      return this;
   }

   private void adjustColors(Color bg, Color fg, Component... components) {
      for (Component c : components) {
         c.setForeground(fg);
         c.setBackground(bg);
      }
   }

   private Icon getImageIcon(final Garment garment, int size) {
      final String imagePath = "resources/" + garment.getClass().getSimpleName().toLowerCase() + "/" + garment.adjective() + ".jpg";
      final URL imageResource = getClass().getResource(imagePath);
      if (imageResource != null) {
         return new ImageIcon(imageResource);
      }
      final String defaultImagePath = "resources/" + garment.getClass().getSimpleName().toLowerCase() + "/default.jpg";
      return new ImageIcon(getClass().getResource(defaultImagePath));
   }
}